==> gfarm2fs_1.2.11.orig.tar.xz: gfarm2fs-1.2.11/gfarm2fs_msg_enums.h <==
#define GFARM_MSG_2000001	2000001
#define GFARM_MSG_2000002	2000002
#define GFARM_MSG_2000003	2000003
#define GFARM_MSG_2000004	2000004
#define GFARM_MSG_2000005	2000005
#define GFARM_MSG_2000006	2000006
#define GFARM_MSG_2000007	2000007
#define GFARM_MSG_2000008	2000008
#define GFARM_MSG_2000009	2000009
#define GFARM_MSG_2000010	2000010
#define GFARM_MSG_2000011	2000011
#define GFARM_MSG_2000012	2000012
#define GFARM_MSG_2000013	2000013
#define GFARM_MSG_2000014	2000014
#define GFARM_MSG_2000015	2000015
#define GFARM_MSG_2000016	2000016
#define GFARM_MSG_2000017	2000017
#define GFARM_MSG_2000018	2000018
#define GFARM_MSG_2000019	2000019
#define GFARM_MSG_2000020	2000020
#define GFARM_MSG_2000021	2000021
#define GFARM_MSG_2000022	2000022
#define GFARM_MSG_2000023	2000023
#define GFARM_MSG_2000024	2000024
#define GFARM_MSG_2000025	2000025
#define GFARM_MSG_2000026	2000026
#define GFARM_MSG_2000027	2000027
#define GFARM_MSG_2000028	2000028
#define GFARM_MSG_2000029	2000029
#define GFARM_MSG_2000030	2000030
#define GFARM_MSG_2000031	2000031
#define GFARM_MSG_2000032	2000032
#define GFARM_MSG_2000033	2000033
#define GFARM_MSG_2000034	2000034
#define GFARM_MSG_2000035	2000035
#define GFARM_MSG_2000036	2000036
#define GFARM_MSG_2000037	2000037
#define GFARM_MSG_2000038	2000038
#define GFARM_MSG_2000039	2000039
#define GFARM_MSG_2000040	2000040
#define GFARM_MSG_2000041	2000041
#define GFARM_MSG_2000042	2000042
#define GFARM_MSG_2000043	2000043
#define GFARM_MSG_2000044	2000044
#define GFARM_MSG_2000045	2000045
#define GFARM_MSG_2000046	2000046
#define GFARM_MSG_2000047	2000047
#define GFARM_MSG_2000048	2000048
#define GFARM_MSG_2000049	2000049
#define GFARM_MSG_2000050	2000050
#define GFARM_MSG_2000051	2000051
#define GFARM_MSG_2000052	2000052
#define GFARM_MSG_2000053	2000053
#define GFARM_MSG_2000054	2000054
#define GFARM_MSG_2000055	2000055
#define GFARM_MSG_2000056	2000056
#define GFARM_MSG_2000057	2000057
#define GFARM_MSG_2000058	2000058
#define GFARM_MSG_2000059	2000059
#define GFARM_MSG_2000060	2000060
#define GFARM_MSG_2000061	2000061
#define GFARM_MSG_2000062	2000062
#define GFARM_MSG_2000063	2000063
#define GFARM_MSG_2000064	2000064
#define GFARM_MSG_2000065	2000065
#define GFARM_MSG_2000066	2000066
#define GFARM_MSG_2000067	2000067
#define GFARM_MSG_2000068	2000068
#define GFARM_MSG_2000069	2000069
#define GFARM_MSG_2000070	2000070
#define GFARM_MSG_2000071	2000071
#define GFARM_MSG_2000072	2000072
#define GFARM_MSG_2000073	2000073
#define GFARM_MSG_2000074	2000074
#define GFARM_MSG_2000075	2000075
#define GFARM_MSG_2000076	2000076
#define GFARM_MSG_2000077	2000077
#define GFARM_MSG_2000078	2000078
#define GFARM_MSG_2000079	2000079
#define GFARM_MSG_2000080	2000080
#define GFARM_MSG_2000081	2000081
#define GFARM_MSG_2000082	2000082
#define GFARM_MSG_2000083	2000083
#define GFARM_MSG_2000084	2000084
#define GFARM_MSG_2000085	2000085
#define GFARM_MSG_2000086	2000086
#define GFARM_MSG_2000087	2000087
#define GFARM_MSG_2000088	2000088
#define GFARM_MSG_2000089	2000089
#define GFARM_MSG_2000090	2000090
#define GFARM_MSG_2000091	2000091
#define GFARM_MSG_2000092	2000092
#define GFARM_MSG_2000093	2000093
#define GFARM_MSG_2000094	2000094
#define GFARM_MSG_2000095	2000095
#define GFARM_MSG_2000096	2000096
#define GFARM_MSG_2000097	2000097
#define GFARM_MSG_2000098	2000098
#define GFARM_MSG_2000099	2000099
#define GFARM_MSG_2000100	2000100
#define GFARM_MSG_2000101	2000101
#define GFARM_MSG_2000102	2000102
#define GFARM_MSG_2000103	2000103
#define GFARM_MSG_2000104	2000104
#define GFARM_MSG_2000105	2000105
#define GFARM_MSG_2000106	2000106
#define GFARM_MSG_2000107	2000107
#define GFARM_MSG_2000108	2000108
#define GFARM_MSG_2000109	2000109
#define GFARM_MSG_2000110	2000110
#define GFARM_MSG_2000111	2000111
#define GFARM_MSG_2000112	2000112
#define GFARM_MSG_2000113	2000113
#define GFARM_MSG_2000114	2000114
#define GFARM_MSG_2000115	2000115
#define GFARM_MSG_2000116	2000116
#define GFARM_MSG_2000117	2000117
#define GFARM_MSG_2000118	2000118
#define GFARM_MSG_2000119	2000119
#define GFARM_MSG_2000120	2000120
#define GFARM_MSG_2000121	2000121
#define GFARM_MSG_2000122	2000122
#define GFARM_MSG_2000123	2000123
#define GFARM_MSG_2000124	2000124
#define GFARM_MSG_2000125	2000125
#define GFARM_MSG_2000126	2000126

==> gfarm2fs_1.2.16.orig.tar.xz: gfarm2fs-1.2.16/gfarm2fs_msg_enums.h <==
#define GFARM_MSG_2000001	2000001
#define GFARM_MSG_2000002	2000002
#define GFARM_MSG_2000003	2000003
#define GFARM_MSG_2000004	2000004
#define GFARM_MSG_2000005	2000005
#define GFARM_MSG_2000006	2000006
#define GFARM_MSG_2000007	2000007
#define GFARM_MSG_2000008	2000008
#define GFARM_MSG_2000009	2000009
#define GFARM_MSG_2000010	2000010
#define GFARM_MSG_2000011	2000011
#define GFARM_MSG_2000012	2000012
#define GFARM_MSG_2000013	2000013
#define GFARM_MSG_2000014	2000014
#define GFARM_MSG_2000015	2000015
#define GFARM_MSG_2000016	2000016
#define GFARM_MSG_2000017	2000017
#define GFARM_MSG_2000018	2000018
#define GFARM_MSG_2000019	2000019
#define GFARM_MSG_2000020	2000020
#define GFARM_MSG_2000021	2000021
#define GFARM_MSG_2000022	2000022
#define GFARM_MSG_2000023	2000023
#define GFARM_MSG_2000024	2000024
#define GFARM_MSG_2000025	2000025
#define GFARM_MSG_2000026	2000026
#define GFARM_MSG_2000027	2000027
#define GFARM_MSG_2000028	2000028
#define GFARM_MSG_2000029	2000029
#define GFARM_MSG_2000030	2000030
#define GFARM_MSG_2000031	2000031
#define GFARM_MSG_2000032	2000032
#define GFARM_MSG_2000033	2000033
#define GFARM_MSG_2000034	2000034
#define GFARM_MSG_2000035	2000035
#define GFARM_MSG_2000036	2000036
#define GFARM_MSG_2000037	2000037
#define GFARM_MSG_2000038	2000038
#define GFARM_MSG_2000039	2000039
#define GFARM_MSG_2000040	2000040
#define GFARM_MSG_2000041	2000041
#define GFARM_MSG_2000042	2000042
#define GFARM_MSG_2000043	2000043
#define GFARM_MSG_2000044	2000044
#define GFARM_MSG_2000045	2000045
#define GFARM_MSG_2000046	2000046
#define GFARM_MSG_2000047	2000047
#define GFARM_MSG_2000048	2000048
#define GFARM_MSG_2000049	2000049
#define GFARM_MSG_2000050	2000050
#define GFARM_MSG_2000051	2000051
#define GFARM_MSG_2000052	2000052
#define GFARM_MSG_2000053	2000053
#define GFARM_MSG_2000054	2000054
#define GFARM_MSG_2000055	2000055
#define GFARM_MSG_2000056	2000056
#define GFARM_MSG_2000057	2000057
#define GFARM_MSG_2000058	2000058
#define GFARM_MSG_2000059	2000059
#define GFARM_MSG_2000060	2000060
#define GFARM_MSG_2000061	2000061
#define GFARM_MSG_2000062	2000062
#define GFARM_MSG_2000063	2000063
#define GFARM_MSG_2000064	2000064
#define GFARM_MSG_2000065	2000065
#define GFARM_MSG_2000066	2000066
#define GFARM_MSG_2000067	2000067
#define GFARM_MSG_2000068	2000068
#define GFARM_MSG_2000069	2000069
#define GFARM_MSG_2000070	2000070
#define GFARM_MSG_2000071	2000071
#define GFARM_MSG_2000072	2000072
#define GFARM_MSG_2000073	2000073
#define GFARM_MSG_2000074	2000074
#define GFARM_MSG_2000075	2000075
#define GFARM_MSG_2000076	2000076
#define GFARM_MSG_2000077	2000077
#define GFARM_MSG_2000078	2000078
#define GFARM_MSG_2000079	2000079
#define GFARM_MSG_2000080	2000080
#define GFARM_MSG_2000081	2000081
#define GFARM_MSG_2000082	2000082
#define GFARM_MSG_2000083	2000083
#define GFARM_MSG_2000084	2000084
#define GFARM_MSG_2000085	2000085
#define GFARM_MSG_2000086	2000086
#define GFARM_MSG_2000087	2000087
#define GFARM_MSG_2000088	2000088
#define GFARM_MSG_2000089	2000089
#define GFARM_MSG_2000090	2000090
#define GFARM_MSG_2000091	2000091
#define GFARM_MSG_2000092	2000092
#define GFARM_MSG_2000093	2000093
#define GFARM_MSG_2000094	2000094
#define GFARM_MSG_2000095	2000095
#define GFARM_MSG_2000096	2000096
#define GFARM_MSG_2000097	2000097
#define GFARM_MSG_2000098	2000098
#define GFARM_MSG_2000099	2000099
#define GFARM_MSG_2000100	2000100
#define GFARM_MSG_2000101	2000101
#define GFARM_MSG_2000102	2000102
#define GFARM_MSG_2000103	2000103
#define GFARM_MSG_2000104	2000104
#define GFARM_MSG_2000105	2000105
#define GFARM_MSG_2000106	2000106
#define GFARM_MSG_2000107	2000107
#define GFARM_MSG_2000108	2000108
#define GFARM_MSG_2000109	2000109
#define GFARM_MSG_2000110	2000110
#define GFARM_MSG_2000111	2000111
#define GFARM_MSG_2000112	2000112
#define GFARM_MSG_2000113	2000113
#define GFARM_MSG_2000114	2000114
#define GFARM_MSG_2000115	2000115
#define GFARM_MSG_2000116	2000116
#define GFARM_MSG_2000117	2000117
#define GFARM_MSG_2000118	2000118
#define GFARM_MSG_2000119	2000119
#define GFARM_MSG_2000120	2000120
#define GFARM_MSG_2000121	2000121
#define GFARM_MSG_2000122	2000122
#define GFARM_MSG_2000123	2000123
#define GFARM_MSG_2000124	2000124
#define GFARM_MSG_2000125	2000125
#define GFARM_MSG_2000126	2000126
#define GFARM_MSG_2000127	2000127
#define GFARM_MSG_2000128	2000128
#define GFARM_MSG_2000129	2000129
#define GFARM_MSG_2000130	2000130
